/* Copyright (C) 2007-2009 The MorphOS Team. All rights reserved.
 *
 * $Id: etina.c,v 1.7 2012/01/08 00:45:02 tokai Exp $
 */

/// includes

#define __NOLIBBASE__
#define USE_INLINE_STDARG

#include <exec/resident.h>
#include <exec/libraries.h>
#include <libraries/locale.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/locale.h>

#include "language.h"

#define LIBNAME "etina.language"
#define VERSION         51
#define REVISION        3
#define DATE    __AMIGADATE__
#define VERS    LIBNAME " 51.3"
#define VSTRING VERS " (" DATE ")  2007-"__COPYRIGHTYEAR__" Lukas Stehlik, MorphOS Team\r\n"
#define VERSTAG "\0$VER: " VSTRING

///
/// basic defs and structures

struct LanguageBase
{
	struct Library          	LibNode;
	APTR                    	Seglist;
	struct SignalSemaphore	SemLock;
};

struct Library *SysBase;
struct Library *LocaleBase;

static const CONST_WSTRPTR CzechStringsU[];
static const STRPTR CzechStrings[];
static const UBYTE CzechToLower[];
static const UBYTE CzechToUpper[];
static const UWORD CzechCTypes[];
static const UBYTE CzechCollate1[];
static const UBYTE CzechCollate2[];

#define MKBYTE(c,b) (((c) & ~0xFF) | (b))
#define MKBOOL(c,b) (((c) & ~0xFF) | ((b) ? 0xFF : 0))

///
/// protos

/* standards */

struct Library *LibInit(struct Library *unused, APTR seglist, struct Library *sysb);
struct LanguageBase *lib_init(struct LanguageBase *cb, APTR seglist, struct Library *SysBase);
APTR lib_expunge(struct LanguageBase *cb);
struct Library *LibOpen(void);
ULONG LibClose(void);
APTR LibExpunge(void);
ULONG LibReserved(void);
LONG dummy_function(void);
BOOL InitResources(struct LanguageBase *cb);
void FreeResources(struct LanguageBase *cb);

/* specific */

ULONG LibLanguageMask(void);
STRPTR LibGetLangString(void);
ULONG LibConvToLower(void);
ULONG LibConvToUpper(void);
ULONG LibIsAlnum(void);
ULONG LibIsAlpha(void);
ULONG LibIsCntrl(void);
ULONG LibIsDigit(void);
ULONG LibIsGraph(void);
ULONG LibIsLower(void);
ULONG LibIsPrint(void);
ULONG LibIsPunct(void);
ULONG LibIsSpace(void);
ULONG LibIsUpper(void);
ULONG LibIsXDigit(void);
LONG LibStrCompare(void);
CONST_WSTRPTR LibGetLangStringU(ULONG id, struct LocaleBase *LocaleBase);

/* Czech Unicode characters HEX codes */

#define Aacute 0x00c1
#define aacute 0x00e1
#define Ccaron 0x010c
#define ccaron 0x010d
#define Dcaron 0x010e
#define dcaron 0x010f
#define Eacute 0x00c9
#define eacute 0x00e9
#define Ecaron 0x011a
#define ecaron 0x011b
#define Iacute 0x00cd
#define iacute 0x00ed
#define Ncaron 0x0147
#define ncaron 0x0148
#define Rcaron 0x0158
#define rcaron 0x0159
#define Scaron 0x0160
#define scaron 0x0161
#define Tcaron 0x0164
#define tcaron 0x0165
#define Uacute 0x00da
#define uacute 0x00fa
#define Uring  0x016e
#define uring  0x016f
#define Yacute 0x00dd
#define yacute 0x00fd
#define Zcaron 0x017d
#define zcaron 0x017e

///
/// dummy_function()

LONG dummy_function(void)
{
	return -1;
}

///
/// resident

const UBYTE LibName[] = LIBNAME;
const UBYTE VTag[] = VERSTAG;

const struct Resident __attribute__((section(".text"))) ROMTag =
{
	RTC_MATCHWORD,
	(APTR)&ROMTag,
	(APTR)&ROMTag + 1,
	RTF_EXTENDED | RTF_PPC,
	VERSION,
	NT_LIBRARY,
	-120,
	(STRPTR)LibName,
	VSTRING,
	(APTR)LibInit
	, REVISION,
	NULL
};

const CONST_APTR JumpTable[] =
{
	(CONST_APTR) FUNCARRAY_BEGIN,
	(APTR)FUNCARRAY_32BIT_NATIVE,
	(APTR)LibOpen,
	(APTR)LibClose,
	(APTR)LibExpunge,
	(APTR)LibReserved,
	(APTR)LibLanguageMask,
	(APTR)LibConvToLower,
	(APTR)LibConvToUpper,
	(APTR)LibReserved,      // Private2 (Undocumented? Reserved?)
	(APTR)LibGetLangString,
	(APTR)LibIsAlnum,
	(APTR)LibIsAlpha,
	(APTR)LibIsCntrl,
	(APTR)LibIsDigit,
	(APTR)LibIsGraph,
	(APTR)LibIsLower,
	(APTR)LibIsPrint,
	(APTR)LibIsPunct,
	(APTR)LibIsSpace,
	(APTR)LibIsUpper,
	(APTR)LibIsXDigit,
	(APTR)LibReserved,      // for StrConvert
	(APTR)LibStrCompare,
	(APTR)0xFFFFFFFF,

	/* 17 */
	(APTR) FUNCARRAY_32BIT_SYSTEMV,
	&LibGetLangStringU,
	(APTR) - 1L,

	(CONST_APTR) FUNCARRAY_END
};

///
/// InitResources()

BOOL InitResources(struct LanguageBase *cb)
{
	return TRUE;
}

///
/// FreeResources()

void FreeResources(struct LanguageBase *cb)
{
	return;
}

///
/// LibInit()

struct LanguageBase *lib_init(struct LanguageBase *cb, APTR seglist, struct Library *sysbase)
{
	sysbase = sysbase;            // Suppresses "unused variable" warning.
	cb->Seglist = seglist;

	InitSemaphore(&cb->SemLock);

	return cb;
}

struct Library *LibInit(struct Library *unused, APTR seglist, struct Library *sysbase)
{
	unused = unused;      /* suppress warning */
	SysBase = sysbase;

	return (NewCreateLibraryTags(
	            LIBTAG_FUNCTIONINIT, (ULONG)JumpTable,
	            LIBTAG_LIBRARYINIT, (ULONG)lib_init,
	            LIBTAG_MACHINE,      MACHINE_PPC,
	            LIBTAG_BASESIZE,     sizeof(struct LanguageBase),
	            LIBTAG_SEGLIST, (ULONG)seglist,
	            LIBTAG_TYPE,         NT_LIBRARY,
	            LIBTAG_PRI,          -120,
	            LIBTAG_NAME, (ULONG)ROMTag.rt_Name,
	            LIBTAG_IDSTRING, (ULONG)ROMTag.rt_IdString,
	            LIBTAG_FLAGS,        LIBF_CHANGED | LIBF_SUMUSED,
	            LIBTAG_VERSION,      VERSION,
	            LIBTAG_REVISION,     REVISION,
	            LIBTAG_PUBLIC,       TRUE,
	            TAG_END));
}

///
/// LibOpen()

struct Library *LibOpen(void)
{
	struct LanguageBase *cb = (struct LanguageBase*)REG_A6;
	struct Library *lib = (struct Library*)cb;

	ObtainSemaphore(&cb->SemLock);

	if(!LocaleBase)
	{

		LocaleBase = OpenLibrary("locale.library", 51);

		if(!LocaleBase)
		{
			lib = NULL;
		}
	}
	ReleaseSemaphore(&cb->SemLock);

#warning this is possibly unprotected, should move to start of function. In failure case decreased again.
	if(lib)
	{
		cb->LibNode.lib_Flags &= ~LIBF_DELEXP;
		cb->LibNode.lib_OpenCnt++;
	}

	return lib;
}

///
/// LibClose()

ULONG LibClose(void)
{
	struct LanguageBase *cb = (struct LanguageBase*)REG_A6;
	ULONG ret = 0;

	ObtainSemaphore(&cb->SemLock);
	if(--cb->LibNode.lib_OpenCnt == 0)
	{
		CloseLibrary((struct Library *)LocaleBase);
		LocaleBase = NULL;
		if(cb->LibNode.lib_Flags & LIBF_DELEXP) ret = (ULONG)lib_expunge(cb);
	}
	ReleaseSemaphore(&cb->SemLock);
	return ret;
}

///
/// LibExpunge()

APTR LibExpunge(void)
{
	struct LanguageBase *cb = (struct LanguageBase*)REG_A6;

	return(lib_expunge(cb));
}


APTR lib_expunge(struct LanguageBase *cb)
{
	APTR seglist = NULL;

	if(cb->LibNode.lib_OpenCnt == 0)
	{
		REMOVE((struct Node*)cb);
		FreeResources(cb);
		seglist = cb->Seglist;
		FreeMem((UBYTE*)cb - cb->LibNode.lib_NegSize, cb->LibNode.lib_NegSize + cb->LibNode.lib_PosSize);
		cb = NULL;    /* freed memory, no more valid */
	}
	else cb->LibNode.lib_Flags |= LIBF_DELEXP;

	return seglist;
}

///
/// LibReserved()

ULONG LibReserved(void)
{
	return 0;
}

///
/// LibLanguageMask()

ULONG LibLanguageMask(void)
{
	return (LF_ConvToLower | LF_ConvToUpper | LF_GetLangStr | LF_IsAlNum |
	        LF_IsAlpha | LF_IsCntrl | LF_IsDigit | LF_IsGraph | LF_IsLower |
	        LF_IsPrint | LF_IsPunct | LF_IsSpace | LF_IsUpper | LF_IsXDigit |
	        LF_ToUpper | LF_StringComp | LF_GetLangStrU);
}

///
/// LibGetLangStringU()

CONST_WSTRPTR LibGetLangStringU(ULONG id, struct LocaleBase *LocaleBase)
{
	if(id < MAXSTRMSG)
		return CzechStringsU[id];
	else
		return NULL;
}

///
/// LibGetLangString()

STRPTR LibGetLangString(void)
{
	ULONG id = REG_D0;

	if(id < MAXSTRMSG) return CzechStrings[id];
	else return NULL;
}

///
/// LibConvToLower()

ULONG LibConvToLower(void)
{
	ULONG chr = REG_D0;

	return MKBYTE(chr, CzechToLower[(UBYTE)chr]);
}

///
/// LibConvToUpper()

ULONG LibConvToUpper(void)
{
	ULONG chr = REG_D0;

	return MKBYTE(chr, CzechToUpper[(UBYTE)chr]);
}

///
/// LibIsAlnum()

ULONG LibIsAlnum(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iAlNum);
}

///
/// LibIsAlpha()

ULONG LibIsAlpha(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iAlpha);
}

///
/// LibIsCntrl()

ULONG LibIsCntrl(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iCntrl);
}

///
/// LibIsDigit()

ULONG LibIsDigit(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iDigit);
}

///
/// LibIsGraph()

ULONG LibIsGraph(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iGraph);
}

///
/// LibIsLower()

ULONG LibIsLower(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iLower);
}

///
/// LibIsPrint()

ULONG LibIsPrint(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iPrint);
}

///
/// LibIsPunct()

ULONG LibIsPunct(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iPunct);
}

///
/// LibIsSpace()

ULONG LibIsSpace(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iSpace);
}

///
/// LibIsUpper()

ULONG LibIsUpper(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iUpper);
}

///
/// LibIsXDigit()

ULONG LibIsXDigit(void)
{
	ULONG chr = REG_D0;

	return MKBOOL(chr, CzechCTypes[(UBYTE)chr] & iXDigit);
}

///
/// LibStrCompare()

LONG LibStrCompare(void)
{
	STRPTR string1 = (STRPTR)REG_A1;
	STRPTR string2 = (STRPTR)REG_A2;
	LONG length = REG_D0;
	ULONG type = REG_D1;

	CONST UBYTE *coll_tab;

	switch(type)
	{
	case SC_ASCII:
		coll_tab = CzechToUpper;
		break;
	case SC_COLLATE1:
		coll_tab = CzechCollate1;
		break;
	case SC_COLLATE2:
		coll_tab = CzechCollate2;
		break;
	default:
		return 0;
	}

	// CH ... after H before I
	// CzechCollate1: C=43, H=48, I=50 -> CH ... 49
	// CzechCollate2: C=48, H=56, I=58 -> CH ... 57

	return StrCompareInternal(string1, string2, length, coll_tab, CzechCTypes);
}

///
/// CzechStringsU[]

// Strings with Czech diacritic characters have to be defined as ULONG tables:

STATIC CONST ULONG CzechMonday[] = {'p', 'o', 'n', 'd', ecaron, 'l', iacute, 0x0000};
STATIC CONST ULONG CzechTuesday[] = {uacute, 't', 'e', 'r', yacute, 0x0000};
STATIC CONST ULONG CzechWednesday[] = {'s', 't', rcaron, 'e', 'd', 'a', 0x0000};
STATIC CONST ULONG CzechThursday[] = {ccaron, 't', 'v', 'r', 't', 'e', 'k', 0x0000};
STATIC CONST ULONG CzechFriday[] = {'p', aacute, 't', 'e', 'k', 0x0000};
STATIC CONST ULONG CzechSunday[] = {'n', 'e', 'd', ecaron, 'l', 'e', 0x0000};
STATIC CONST ULONG CzechTu[] = {uacute, 't', 0x0000};
STATIC CONST ULONG CzechTh[] = {ccaron, 't', 0x0000};
STATIC CONST ULONG CzechFr[] = {'p', aacute, 0x0000};
STATIC CONST ULONG CzechFebruary[] = {uacute, 'n', 'o', 'r', 0x0000};
STATIC CONST ULONG CzechMarch[] = {'b', rcaron, 'e', 'z', 'e', 'n', 0x0000};
STATIC CONST ULONG CzechMay[] = {'k', 'v', ecaron, 't', 'e', 'n', 0x0000};
STATIC CONST ULONG CzechJune[] = {ccaron, 'e', 'r', 'v', 'e', 'n', 0x0000};
STATIC CONST ULONG CzechJuly[] = {ccaron, 'e', 'r', 'v', 'e', 'n', 'e', 'c', 0x0000};
STATIC CONST ULONG CzechSeptember[] = {'z', aacute, rcaron, iacute, 0x0000};
STATIC CONST ULONG CzechOctober[] = {rcaron, iacute, 'j', 'e', 'n', 0x0000};
STATIC CONST ULONG CzechFeb[] = {uacute, 'n', 'o', 0x0000};
STATIC CONST ULONG CzechMar[] = {'b', rcaron, 'e', 0x0000};
STATIC CONST ULONG CzechMay3[] = {'k', 'v', ecaron, 0x0000};
STATIC CONST ULONG CzechJun[] = {ccaron, 'e', 'n', 0x0000};
STATIC CONST ULONG CzechJul[] = {ccaron, 'e', 'c', 0x0000};
STATIC CONST ULONG CzechSep[] = {'z', aacute, rcaron, 0x0000};
STATIC CONST ULONG CzechOct[] = {rcaron, iacute, 'j', 0x0000};
STATIC CONST ULONG CzechOpenQuote[] = {0x201e, 0x0000};  // DOUBLE LOW-9 QUOTATION MARK
STATIC CONST ULONG CzechCloseQuote[] = {0x201d, 0x0000}; // RIGHT DOUBLE QUOTATION MARK
STATIC CONST ULONG CzechYesterday[] = {'v', ccaron, 'e', 'r', 'a', 0x0000};
STATIC CONST ULONG CzechTomorrow[] = {'z', iacute, 't', 'r', 'a', 0x0000};

static const CONST_WSTRPTR CzechStringsU[] =
{
	/* A blank string */

	(CONST_WSTRPTR)L"",

	/*  The days of the week. Starts with the first day of the week.
	        In English this would be Sunday, this depends upon the settings
	        of Locale->CalendarType. */

	(CONST_WSTRPTR)CzechTuesday,
	(CONST_WSTRPTR)CzechWednesday,
	(CONST_WSTRPTR)CzechThursday,
	(CONST_WSTRPTR)CzechFriday,
	(CONST_WSTRPTR)L"sobota",
	(CONST_WSTRPTR)CzechSunday,
	(CONST_WSTRPTR)CzechMonday,

	/* Abbreviated days of the week */

	(CONST_WSTRPTR)CzechTu, (CONST_WSTRPTR)L"st", (CONST_WSTRPTR)CzechTh, (CONST_WSTRPTR)CzechFr, (CONST_WSTRPTR)L"so", (CONST_WSTRPTR)L"ne", (CONST_WSTRPTR)L"po",

	/* Months of the year */

	(CONST_WSTRPTR)L"leden", (CONST_WSTRPTR)CzechFebruary, (CONST_WSTRPTR)CzechMarch, (CONST_WSTRPTR)L"duben", (CONST_WSTRPTR)CzechMay, (CONST_WSTRPTR)CzechJune,
	(CONST_WSTRPTR)CzechJuly, (CONST_WSTRPTR)L"srpen", (CONST_WSTRPTR)CzechSeptember, (CONST_WSTRPTR)CzechOctober, (CONST_WSTRPTR)L"listopad", (CONST_WSTRPTR)L"prosinec",

	/* Abbreviated months of the year */

	(CONST_WSTRPTR)L"led", (CONST_WSTRPTR)CzechFeb, (CONST_WSTRPTR)CzechMar, (CONST_WSTRPTR)L"dub", (CONST_WSTRPTR)CzechMay3, (CONST_WSTRPTR)CzechJun,
	(CONST_WSTRPTR)CzechJul, (CONST_WSTRPTR)L"srp", (CONST_WSTRPTR)CzechSep, (CONST_WSTRPTR)CzechOct, (CONST_WSTRPTR)L"lis", (CONST_WSTRPTR)L"pro",

	(CONST_WSTRPTR)L"Ano", /* Yes, affirmative response */
	(CONST_WSTRPTR)L"Ne", /* No/negative response */

	/* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */

	(CONST_WSTRPTR)L"dopoledne", (CONST_WSTRPTR)L"odpoledne",

	/* Soft and hard hyphens */

	(CONST_WSTRPTR)L"-", (CONST_WSTRPTR)L"-",

	/* Open and close quotes */

	(CONST_WSTRPTR)CzechOpenQuote, (CONST_WSTRPTR)CzechCloseQuote,

	/* Days: But not actual day names
	   Yesterday - the day before the current
	   Today - the current day
	   Tomorrow - the next day
	   Future.
	*/

	(CONST_WSTRPTR)CzechYesterday, (CONST_WSTRPTR)L"dnes", (CONST_WSTRPTR)CzechTomorrow, (CONST_WSTRPTR)L"budoucnost"
};

///
/// CzechStrings[]

static const STRPTR CzechStrings[] =
{
	/* A blank string */

	"",

	/*  The days of the week. Starts with the first day of the week.
	        In English this would be Sunday, this depends upon the settings
	        of Locale->CalendarType. */

	"nedle",
	"pondl", "ter", "steda", "tvrtek", "ptek",
	"sobota",

	/* Abbreviated days of the week */

	"ne", "po", "t", "st", "t", "p", "so",

	/* Months of the year */

	"leden", "nor", "bezen", "duben", "kvten", "erven",
	"ervenec", "srpen", "z", "jen", "listopad", "prosinec",

	/* Abbreviated months of the year */

	"led", "no", "be", "dub", "kv", "en",
	"ec", "srp", "z", "j", "lis", "pro",

	"Ano", /* Yes, affirmative response */
	"Ne", /* No/negative response */

	/* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */

	"dopoledne", "odpoledne",

	/* Soft and hard hyphens */

	"-", "-",

	/* Open and close quotes */

	"\"", "\"",

	/* Days: But not actual day names
	   Yesterday - the day before the current
	   Today - the current day
	   Tomorrow - the next day
	   Future.
	*/

	"vera", "dnes", "ztra", "budoucnost"
};

///
/// CzechCTypes[]

static const UWORD CzechCTypes[256] =
{
	iCntrl, /* NULL */
	iCntrl, /* START OF HEADING */
	iCntrl, /* START OF TEXT */
	iCntrl, /* END OF TEXT */
	iCntrl, /* END OF TRANSMISSION */
	iCntrl, /* ENQUIRY */
	iCntrl, /* ACKNOWLEDGE */
	iCntrl, /* BELL */
	iCntrl | iPrint | iSpace, /* BACKSPACE */
	iCntrl | iPrint | iSpace, /* HORIZONTAL TABULATION */
	iCntrl | iPrint | iSpace, /* LINE FEED */
	iCntrl | iPrint | iSpace, /* VERTICAL TABULATION */
	iCntrl | iPrint | iSpace, /* FORM FEED */
	iCntrl | iPrint | iSpace, /* CARRIAGE RETURN */
	iCntrl, /* SHIFT OUT */
	iCntrl, /* SHIFT IN */
	iCntrl, /* DATA LINK ESCAPE */
	iCntrl, /* DEVICE CONTROL ONE */
	iCntrl, /* DEVICE CONTROL TWO */
	iCntrl, /* DEVICE CONTROL THREE */
	iCntrl, /* DEVICE CONTROL FOUR */
	iCntrl, /* NEGATIVE ACKNOWLEDGE */
	iCntrl, /* SYNCHRONOUS IDLE */
	iCntrl, /* END OF TRANSMISSION BLOCK */
	iCntrl, /* CANCEL */
	iCntrl, /* END OF MEDIUM */
	iCntrl, /* SUBSTITUTE */
	iCntrl, /* ESCAPE */
	iCntrl, /* FILE SEPARATOR */
	iCntrl, /* GROUP SEPARATOR */
	iCntrl, /* RECORD SEPARATOR */
	iCntrl, /* UNIT SEPARATOR */

	iPrint | iSpace, /* SPACE */
	iGraph | iPrint | iPunct, /* EXCLAMATION MARK */
	iGraph | iPrint | iPunct, /* QUOTATION MARK */
	iGraph | iPrint | iPunct, /* NUMBER SIGN */
	iGraph | iPrint | iPunct, /* DOLLAR SIGN */
	iGraph | iPrint | iPunct, /* PERCENT SIGN */
	iGraph | iPrint | iPunct, /* AMPERSAND */
	iGraph | iPrint | iPunct, /* APOSTROPHE */
	iGraph | iPrint | iPunct, /* LEFT PARENTHESIS */
	iGraph | iPrint | iPunct, /* RIGHT PARENTHESIS */
	iGraph | iPrint | iPunct, /* ASTERISK */
	iGraph | iPrint | iPunct, /* PLUS SIGN */
	iGraph | iPrint | iPunct, /* COMMA */
	iGraph | iPrint | iPunct, /* HYPHEN-MINUS */
	iGraph | iPrint | iPunct, /* FULL STOP */
	iGraph | iPrint | iPunct, /* SOLIDUS */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT ZERO */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT ONE */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT TWO */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT THREE */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT FOUR */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT FIVE */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT SIX */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT SEVEN */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT EIGHT */
	iGraph | iPrint | iDigit | iXDigit, /* DIGIT NINE */
	iGraph | iPrint | iPunct, /* COLON */
	iGraph | iPrint | iPunct, /* SEMICOLON */
	iGraph | iPrint | iPunct, /* LESS-THAN SIGN */
	iGraph | iPrint | iPunct, /* EQUALS SIGN */
	iGraph | iPrint | iPunct, /* GREATER-THAN SIGN */
	iGraph | iPrint | iPunct, /* QUESTION MARK */

	iGraph | iPrint | iPunct, /* COMMERCIAL AT */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER A */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER B */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER C */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER D */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER E */
	iAlpha | iGraph | iPrint | iUpper | iXDigit, /* LATIN CAPITAL LETTER F */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER G */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER H */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER J */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER K */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER M */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER P */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Q */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER V */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER W */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER X */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Y */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z */
	iGraph | iPrint | iPunct, /* LEFT SQUARE BRACKET */
	iGraph | iPrint | iPunct, /* REVERSE SOLIDUS */
	iGraph | iPrint | iPunct, /* RIGHT SQUARE BRACKET */
	iGraph | iPrint | iPunct, /* CIRCUMFLEX ACCENT */
	iGraph | iPrint | iPunct, /* LOW LINE */

	iGraph | iPrint | iPunct, /* GRAVE ACCENT */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER A */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER B */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER C */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER D */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER E */
	iAlpha | iGraph | iLower | iPrint | iXDigit, /* LATIN SMALL LETTER F */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER G */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER H */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER J */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER K */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER M */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER P */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Q */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER V */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER W */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER X */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Y */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z */
	iGraph | iPrint | iPunct, /* LEFT CURLY BRACKET */
	iGraph | iPrint | iPunct, /* VERTICAL LINE */
	iGraph | iPrint | iPunct, /* RIGHT CURLY BRACKET */
	iGraph | iPrint | iPunct, /* TILDE */
	iCntrl, /* DELETE */

	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */
	iCntrl, /* <control> */

	iPrint | iPunct, /* NO-BREAK SPACE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH OGONEK */
	iGraph | iPrint, /* BREVE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH STROKE */
	iGraph | iPrint | iPunct, /* CURRENCY SIGN */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH ACUTE */
	iGraph | iPrint | iPunct, /* SECTION SIGN */
	iGraph | iPrint, /* DIAERESIS */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER S WITH CEDILLA */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH ACUTE */
	iGraph | iPrint | iPunct, /* SOFT HYPHEN */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
	iGraph | iPrint | iPunct, /* DEGREE SIGN */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH OGONEK */
	iGraph | iPrint, /* OGONEK */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH STROKE */
	iGraph | iPrint, /* ACUTE ACCENT */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH ACUTE */
	iGraph | iPrint, /* CARON */
	iGraph | iPrint, /* CEDILLA */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER S WITH CEDILLA */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH ACUTE */
	iGraph | iPrint, /* DOUBLE ACUTE ACCENT */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH BREVE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER L WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH CEDILLA */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER C WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH OGONEK */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER E WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER D WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER D WITH STROKE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER N WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
	iGraph | iPrint | iPunct, /* MULTIPLICATION SIGN */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER R WITH CARON */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER Y WITH ACUTE */
	iAlpha | iGraph | iPrint | iUpper, /* LATIN CAPITAL LETTER T WITH CEDILLA */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER SHARP S */

	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH BREVE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER A WITH DIAERESIS */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER L WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH CEDILLA */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER C WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH OGONEK */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH DIAERESIS */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER E WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER D WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER D WITH STROKE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER N WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER O WITH DIAERESIS */
	iGraph | iPrint | iPunct, /* DIVISION SIGN */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER R WITH CARON */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH RING ABOVE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER U WITH DIAERESIS */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER Y WITH ACUTE */
	iAlpha | iGraph | iLower | iPrint, /* LATIN SMALL LETTER T WITH CEDILLA */
	iGraph | iPrint, /* DOT ABOVE */
};

///
/// CzechToLower[]

// This table can be used without changes in all languages using ISO-8859-2
// encoding. [krashan]

static const UBYTE CzechToLower[256] =
{
	0x00, /* NULL */
	0x01, /* START OF HEADING */
	0x02, /* START OF TEXT */
	0x03, /* END OF TEXT */
	0x04, /* END OF TRANSMISSION */
	0x05, /* ENQUIRY */
	0x06, /* ACKNOWLEDGE */
	0x07, /* BELL */
	0x08, /* BACKSPACE */
	0x09, /* HORIZONTAL TABULATION */
	0x0A, /* LINE FEED */
	0x0B, /* VERTICAL TABULATION */
	0x0C, /* FORM FEED */
	0x0D, /* CARRIAGE RETURN */
	0x0E, /* SHIFT OUT */
	0x0F, /* SHIFT IN */
	0x10, /* DATA LINK ESCAPE */
	0x11, /* DEVICE CONTROL ONE */
	0x12, /* DEVICE CONTROL TWO */
	0x13, /* DEVICE CONTROL THREE */
	0x14, /* DEVICE CONTROL FOUR */
	0x15, /* NEGATIVE ACKNOWLEDGE */
	0x16, /* SYNCHRONOUS IDLE */
	0x17, /* END OF TRANSMISSION BLOCK */
	0x18, /* CANCEL */
	0x19, /* END OF MEDIUM */
	0x1A, /* SUBSTITUTE */
	0x1B, /* ESCAPE */
	0x1C, /* FILE SEPARATOR */
	0x1D, /* GROUP SEPARATOR */
	0x1E, /* RECORD SEPARATOR */
	0x1F, /* UNIT SEPARATOR */

	0x20, /* SPACE */
	0x21, /* EXCLAMATION MARK */
	0x22, /* QUOTATION MARK */
	0x23, /* NUMBER SIGN */
	0x24, /* DOLLAR SIGN */
	0x25, /* PERCENT SIGN */
	0x26, /* AMPERSAND */
	0x27, /* APOSTROPHE */
	0x28, /* LEFT PARENTHESIS */
	0x29, /* RIGHT PARENTHESIS */
	0x2A, /* ASTERISK */
	0x2B, /* PLUS SIGN */
	0x2C, /* COMMA */
	0x2D, /* HYPHEN-MINUS */
	0x2E, /* FULL STOP */
	0x2F, /* SOLIDUS */
	0x30, /* DIGIT ZERO */
	0x31, /* DIGIT ONE */
	0x32, /* DIGIT TWO */
	0x33, /* DIGIT THREE */
	0x34, /* DIGIT FOUR */
	0x35, /* DIGIT FIVE */
	0x36, /* DIGIT SIX */
	0x37, /* DIGIT SEVEN */
	0x38, /* DIGIT EIGHT */
	0x39, /* DIGIT NINE */
	0x3A, /* COLON */
	0x3B, /* SEMICOLON */
	0x3C, /* LESS-THAN SIGN */
	0x3D, /* EQUALS SIGN */
	0x3E, /* GREATER-THAN SIGN */
	0x3F, /* QUESTION MARK */

	0x40, /* COMMERCIAL AT */
	0x61, /* LATIN CAPITAL LETTER A */
	0x62, /* LATIN CAPITAL LETTER B */
	0x63, /* LATIN CAPITAL LETTER C */
	0x64, /* LATIN CAPITAL LETTER D */
	0x65, /* LATIN CAPITAL LETTER E */
	0x66, /* LATIN CAPITAL LETTER F */
	0x67, /* LATIN CAPITAL LETTER G */
	0x68, /* LATIN CAPITAL LETTER H */
	0x69, /* LATIN CAPITAL LETTER I */
	0x6A, /* LATIN CAPITAL LETTER J */
	0x6B, /* LATIN CAPITAL LETTER K */
	0x6C, /* LATIN CAPITAL LETTER L */
	0x6D, /* LATIN CAPITAL LETTER M */
	0x6E, /* LATIN CAPITAL LETTER N */
	0x6F, /* LATIN CAPITAL LETTER O */
	0x70, /* LATIN CAPITAL LETTER P */
	0x71, /* LATIN CAPITAL LETTER Q */
	0x72, /* LATIN CAPITAL LETTER R */
	0x73, /* LATIN CAPITAL LETTER S */
	0x74, /* LATIN CAPITAL LETTER T */
	0x75, /* LATIN CAPITAL LETTER U */
	0x76, /* LATIN CAPITAL LETTER V */
	0x77, /* LATIN CAPITAL LETTER W */
	0x78, /* LATIN CAPITAL LETTER X */
	0x79, /* LATIN CAPITAL LETTER Y */
	0x7A, /* LATIN CAPITAL LETTER Z */
	0x5B, /* LEFT SQUARE BRACKET */
	0x5C, /* REVERSE SOLIDUS */
	0x5D, /* RIGHT SQUARE BRACKET */
	0x5E, /* CIRCUMFLEX ACCENT */
	0x5F, /* LOW LINE */

	0x60, /* GRAVE ACCENT */
	0x61, /* LATIN SMALL LETTER A */
	0x62, /* LATIN SMALL LETTER B */
	0x63, /* LATIN SMALL LETTER C */
	0x64, /* LATIN SMALL LETTER D */
	0x65, /* LATIN SMALL LETTER E */
	0x66, /* LATIN SMALL LETTER F */
	0x67, /* LATIN SMALL LETTER G */
	0x68, /* LATIN SMALL LETTER H */
	0x69, /* LATIN SMALL LETTER I */
	0x6A, /* LATIN SMALL LETTER J */
	0x6B, /* LATIN SMALL LETTER K */
	0x6C, /* LATIN SMALL LETTER L */
	0x6D, /* LATIN SMALL LETTER M */
	0x6E, /* LATIN SMALL LETTER N */
	0x6F, /* LATIN SMALL LETTER O */
	0x70, /* LATIN SMALL LETTER P */
	0x71, /* LATIN SMALL LETTER Q */
	0x72, /* LATIN SMALL LETTER R */
	0x73, /* LATIN SMALL LETTER S */
	0x74, /* LATIN SMALL LETTER T */
	0x75, /* LATIN SMALL LETTER U */
	0x76, /* LATIN SMALL LETTER V */
	0x77, /* LATIN SMALL LETTER W */
	0x78, /* LATIN SMALL LETTER X */
	0x79, /* LATIN SMALL LETTER Y */
	0x7A, /* LATIN SMALL LETTER Z */
	0x7B, /* LEFT CURLY BRACKET */
	0x7C, /* VERTICAL LINE */
	0x7D, /* RIGHT CURLY BRACKET */
	0x7E, /* TILDE */
	0x7F, /* DELETE */

	0x80, /* <control> */
	0x81, /* <control> */
	0x82, /* <control> */
	0x83, /* <control> */
	0x84, /* <control> */
	0x85, /* <control> */
	0x86, /* <control> */
	0x87, /* <control> */
	0x88, /* <control> */
	0x89, /* <control> */
	0x8A, /* <control> */
	0x8B, /* <control> */
	0x8C, /* <control> */
	0x8D, /* <control> */
	0x8E, /* <control> */
	0x8F, /* <control> */
	0x90, /* <control> */
	0x91, /* <control> */
	0x92, /* <control> */
	0x93, /* <control> */
	0x94, /* <control> */
	0x95, /* <control> */
	0x96, /* <control> */
	0x97, /* <control> */
	0x98, /* <control> */
	0x99, /* <control> */
	0x9A, /* <control> */
	0x9B, /* <control> */
	0x9C, /* <control> */
	0x9D, /* <control> */
	0x9E, /* <control> */
	0x9F, /* <control> */

	0xA0, /* NO-BREAK SPACE */
	0xB1, /* LATIN CAPITAL LETTER A WITH OGONEK */
	0xA2, /* BREVE */
	0xB3, /* LATIN CAPITAL LETTER L WITH STROKE */
	0xA4, /* CURRENCY SIGN */
	0xB5, /* LATIN CAPITAL LETTER L WITH CARON */
	0xB6, /* LATIN CAPITAL LETTER S WITH ACUTE */
	0xA7, /* SECTION SIGN */
	0xA8, /* DIAERESIS */
	0xB9, /* LATIN CAPITAL LETTER S WITH CARON */
	0xBA, /* LATIN CAPITAL LETTER S WITH CEDILLA */
	0xBB, /* LATIN CAPITAL LETTER T WITH CARON */
	0xBC, /* LATIN CAPITAL LETTER Z WITH ACUTE */
	0xAD, /* SOFT HYPHEN */
	0xBE, /* LATIN CAPITAL LETTER Z WITH CARON */
	0xBF, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
	0xB0, /* DEGREE SIGN */
	0xB1, /* LATIN SMALL LETTER A WITH OGONEK */
	0xB2, /* OGONEK */
	0xB3, /* LATIN SMALL LETTER L WITH STROKE */
	0xB4, /* ACUTE ACCENT */
	0xB5, /* LATIN SMALL LETTER L WITH CARON */
	0xB6, /* LATIN SMALL LETTER S WITH ACUTE */
	0xB7, /* CARON */
	0xB8, /* CEDILLA */
	0xB9, /* LATIN SMALL LETTER S WITH CARON */
	0xBA, /* LATIN SMALL LETTER S WITH CEDILLA */
	0xBB, /* LATIN SMALL LETTER T WITH CARON */
	0xBC, /* LATIN SMALL LETTER Z WITH ACUTE */
	0xBD, /* DOUBLE ACUTE ACCENT */
	0xBE, /* LATIN SMALL LETTER Z WITH CARON */
	0xBF, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

	0xE0, /* LATIN CAPITAL LETTER R WITH ACUTE */
	0xE1, /* LATIN CAPITAL LETTER A WITH ACUTE */
	0xE2, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
	0xE3, /* LATIN CAPITAL LETTER A WITH BREVE */
	0xE4, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
	0xE5, /* LATIN CAPITAL LETTER L WITH ACUTE */
	0xE6, /* LATIN CAPITAL LETTER C WITH ACUTE */
	0xE7, /* LATIN CAPITAL LETTER C WITH CEDILLA */
	0xE8, /* LATIN CAPITAL LETTER C WITH CARON */
	0xE9, /* LATIN CAPITAL LETTER E WITH ACUTE */
	0xEA, /* LATIN CAPITAL LETTER E WITH OGONEK */
	0xEB, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
	0xEC, /* LATIN CAPITAL LETTER E WITH CARON */
	0xED, /* LATIN CAPITAL LETTER I WITH ACUTE */
	0xEE, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
	0xEF, /* LATIN CAPITAL LETTER D WITH CARON */
	0xF0, /* LATIN CAPITAL LETTER D WITH STROKE */
	0xF1, /* LATIN CAPITAL LETTER N WITH ACUTE */
	0xF2, /* LATIN CAPITAL LETTER N WITH CARON */
	0xF3, /* LATIN CAPITAL LETTER O WITH ACUTE */
	0xF4, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
	0xF5, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
	0xF6, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
	0xD7, /* MULTIPLICATION SIGN */
	0xF8, /* LATIN CAPITAL LETTER R WITH CARON */
	0xF9, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
	0xFA, /* LATIN CAPITAL LETTER U WITH ACUTE */
	0xFB, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
	0xFC, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
	0xFD, /* LATIN CAPITAL LETTER Y WITH ACUTE */
	0xFE, /* LATIN CAPITAL LETTER T WITH CEDILLA */
	0xFF, /* LATIN SMALL LETTER SHARP S */

	0xE0, /* LATIN SMALL LETTER R WITH ACUTE */
	0xE1, /* LATIN SMALL LETTER A WITH ACUTE */
	0xE2, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
	0xE3, /* LATIN SMALL LETTER A WITH BREVE */
	0xE4, /* LATIN SMALL LETTER A WITH DIAERESIS */
	0xE5, /* LATIN SMALL LETTER L WITH ACUTE */
	0xE6, /* LATIN SMALL LETTER C WITH ACUTE */
	0xE7, /* LATIN SMALL LETTER C WITH CEDILLA */
	0xE8, /* LATIN SMALL LETTER C WITH CARON */
	0xE9, /* LATIN SMALL LETTER E WITH ACUTE */
	0xEA, /* LATIN SMALL LETTER E WITH OGONEK */
	0xEB, /* LATIN SMALL LETTER E WITH DIAERESIS */
	0xEC, /* LATIN SMALL LETTER E WITH CARON */
	0xED, /* LATIN SMALL LETTER I WITH ACUTE */
	0xEE, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
	0xEF, /* LATIN SMALL LETTER D WITH CARON */
	0xF0, /* LATIN SMALL LETTER D WITH STROKE */
	0xF1, /* LATIN SMALL LETTER N WITH ACUTE */
	0xF2, /* LATIN SMALL LETTER N WITH CARON */
	0xF3, /* LATIN SMALL LETTER O WITH ACUTE */
	0xF4, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
	0xF5, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
	0xF6, /* LATIN SMALL LETTER O WITH DIAERESIS */
	0xF7, /* DIVISION SIGN */
	0xF8, /* LATIN SMALL LETTER R WITH CARON */
	0xF9, /* LATIN SMALL LETTER U WITH RING ABOVE */
	0xFA, /* LATIN SMALL LETTER U WITH ACUTE */
	0xFB, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
	0xFC, /* LATIN SMALL LETTER U WITH DIAERESIS */
	0xFD, /* LATIN SMALL LETTER Y WITH ACUTE */
	0xFE, /* LATIN SMALL LETTER T WITH CEDILLA */
	0xFF  /* DOT ABOVE */
};

///
/// CzechToUpper[]

// This table can be used without changes in all languages using ISO-8859-2
// encoding. [krashan]

static const UBYTE CzechToUpper[256] =
{
	0x00, /* NULL */
	0x01, /* START OF HEADING */
	0x02, /* START OF TEXT */
	0x03, /* END OF TEXT */
	0x04, /* END OF TRANSMISSION */
	0x05, /* ENQUIRY */
	0x06, /* ACKNOWLEDGE */
	0x07, /* BELL */
	0x08, /* BACKSPACE */
	0x09, /* HORIZONTAL TABULATION */
	0x0A, /* LINE FEED */
	0x0B, /* VERTICAL TABULATION */
	0x0C, /* FORM FEED */
	0x0D, /* CARRIAGE RETURN */
	0x0E, /* SHIFT OUT */
	0x0F, /* SHIFT IN */
	0x10, /* DATA LINK ESCAPE */
	0x11, /* DEVICE CONTROL ONE */
	0x12, /* DEVICE CONTROL TWO */
	0x13, /* DEVICE CONTROL THREE */
	0x14, /* DEVICE CONTROL FOUR */
	0x15, /* NEGATIVE ACKNOWLEDGE */
	0x16, /* SYNCHRONOUS IDLE */
	0x17, /* END OF TRANSMISSION BLOCK */
	0x18, /* CANCEL */
	0x19, /* END OF MEDIUM */
	0x1A, /* SUBSTITUTE */
	0x1B, /* ESCAPE */
	0x1C, /* FILE SEPARATOR */
	0x1D, /* GROUP SEPARATOR */
	0x1E, /* RECORD SEPARATOR */
	0x1F, /* UNIT SEPARATOR */

	0x20, /* SPACE */
	0x21, /* EXCLAMATION MARK */
	0x22, /* QUOTATION MARK */
	0x23, /* NUMBER SIGN */
	0x24, /* DOLLAR SIGN */
	0x25, /* PERCENT SIGN */
	0x26, /* AMPERSAND */
	0x27, /* APOSTROPHE */
	0x28, /* LEFT PARENTHESIS */
	0x29, /* RIGHT PARENTHESIS */
	0x2A, /* ASTERISK */
	0x2B, /* PLUS SIGN */
	0x2C, /* COMMA */
	0x2D, /* HYPHEN-MINUS */
	0x2E, /* FULL STOP */
	0x2F, /* SOLIDUS */
	0x30, /* DIGIT ZERO */
	0x31, /* DIGIT ONE */
	0x32, /* DIGIT TWO */
	0x33, /* DIGIT THREE */
	0x34, /* DIGIT FOUR */
	0x35, /* DIGIT FIVE */
	0x36, /* DIGIT SIX */
	0x37, /* DIGIT SEVEN */
	0x38, /* DIGIT EIGHT */
	0x39, /* DIGIT NINE */
	0x3A, /* COLON */
	0x3B, /* SEMICOLON */
	0x3C, /* LESS-THAN SIGN */
	0x3D, /* EQUALS SIGN */
	0x3E, /* GREATER-THAN SIGN */
	0x3F, /* QUESTION MARK */

	0x40, /* COMMERCIAL AT */
	0x41, /* LATIN CAPITAL LETTER A */
	0x42, /* LATIN CAPITAL LETTER B */
	0x43, /* LATIN CAPITAL LETTER C */
	0x44, /* LATIN CAPITAL LETTER D */
	0x45, /* LATIN CAPITAL LETTER E */
	0x46, /* LATIN CAPITAL LETTER F */
	0x47, /* LATIN CAPITAL LETTER G */
	0x48, /* LATIN CAPITAL LETTER H */
	0x49, /* LATIN CAPITAL LETTER I */
	0x4A, /* LATIN CAPITAL LETTER J */
	0x4B, /* LATIN CAPITAL LETTER K */
	0x4C, /* LATIN CAPITAL LETTER L */
	0x4D, /* LATIN CAPITAL LETTER M */
	0x4E, /* LATIN CAPITAL LETTER N */
	0x4F, /* LATIN CAPITAL LETTER O */
	0x50, /* LATIN CAPITAL LETTER P */
	0x51, /* LATIN CAPITAL LETTER Q */
	0x52, /* LATIN CAPITAL LETTER R */
	0x53, /* LATIN CAPITAL LETTER S */
	0x54, /* LATIN CAPITAL LETTER T */
	0x55, /* LATIN CAPITAL LETTER U */
	0x56, /* LATIN CAPITAL LETTER V */
	0x57, /* LATIN CAPITAL LETTER W */
	0x58, /* LATIN CAPITAL LETTER X */
	0x59, /* LATIN CAPITAL LETTER Y */
	0x5A, /* LATIN CAPITAL LETTER Z */
	0x5B, /* LEFT SQUARE BRACKET */
	0x5C, /* REVERSE SOLIDUS */
	0x5D, /* RIGHT SQUARE BRACKET */
	0x5E, /* CIRCUMFLEX ACCENT */
	0x5F, /* LOW LINE */

	0x60, /* GRAVE ACCENT */
	0x41, /* LATIN SMALL LETTER A */
	0x42, /* LATIN SMALL LETTER B */
	0x43, /* LATIN SMALL LETTER C */
	0x44, /* LATIN SMALL LETTER D */
	0x45, /* LATIN SMALL LETTER E */
	0x46, /* LATIN SMALL LETTER F */
	0x47, /* LATIN SMALL LETTER G */
	0x48, /* LATIN SMALL LETTER H */
	0x49, /* LATIN SMALL LETTER I */
	0x4A, /* LATIN SMALL LETTER J */
	0x4B, /* LATIN SMALL LETTER K */
	0x4C, /* LATIN SMALL LETTER L */
	0x4D, /* LATIN SMALL LETTER M */
	0x4E, /* LATIN SMALL LETTER N */
	0x4F, /* LATIN SMALL LETTER O */
	0x50, /* LATIN SMALL LETTER P */
	0x51, /* LATIN SMALL LETTER Q */
	0x52, /* LATIN SMALL LETTER R */
	0x53, /* LATIN SMALL LETTER S */
	0x54, /* LATIN SMALL LETTER T */
	0x55, /* LATIN SMALL LETTER U */
	0x56, /* LATIN SMALL LETTER V */
	0x57, /* LATIN SMALL LETTER W */
	0x58, /* LATIN SMALL LETTER X */
	0x59, /* LATIN SMALL LETTER Y */
	0x5A, /* LATIN SMALL LETTER Z */
	0x7B, /* LEFT CURLY BRACKET */
	0x7C, /* VERTICAL LINE */
	0x7D, /* RIGHT CURLY BRACKET */
	0x7E, /* TILDE */
	0x7F, /* DELETE */

	0x80, /* <control> */
	0x81, /* <control> */
	0x82, /* <control> */
	0x83, /* <control> */
	0x84, /* <control> */
	0x85, /* <control> */
	0x86, /* <control> */
	0x87, /* <control> */
	0x88, /* <control> */
	0x89, /* <control> */
	0x8A, /* <control> */
	0x8B, /* <control> */
	0x8C, /* <control> */
	0x8D, /* <control> */
	0x8E, /* <control> */
	0x8F, /* <control> */
	0x90, /* <control> */
	0x91, /* <control> */
	0x92, /* <control> */
	0x93, /* <control> */
	0x94, /* <control> */
	0x95, /* <control> */
	0x96, /* <control> */
	0x97, /* <control> */
	0x98, /* <control> */
	0x99, /* <control> */
	0x9A, /* <control> */
	0x9B, /* <control> */
	0x9C, /* <control> */
	0x9D, /* <control> */
	0x9E, /* <control> */
	0x9F, /* <control> */

	0xA0, /* NO-BREAK SPACE */
	0xA1, /* LATIN CAPITAL LETTER A WITH OGONEK */
	0xA2, /* BREVE */
	0xA3, /* LATIN CAPITAL LETTER L WITH STROKE */
	0xA4, /* CURRENCY SIGN */
	0xA5, /* LATIN CAPITAL LETTER L WITH CARON */
	0xA6, /* LATIN CAPITAL LETTER S WITH ACUTE */
	0xA7, /* SECTION SIGN */
	0xA8, /* DIAERESIS */
	0xA9, /* LATIN CAPITAL LETTER S WITH CARON */
	0xAA, /* LATIN CAPITAL LETTER S WITH CEDILLA */
	0xAB, /* LATIN CAPITAL LETTER T WITH CARON */
	0xAC, /* LATIN CAPITAL LETTER Z WITH ACUTE */
	0xAD, /* SOFT HYPHEN */
	0xAE, /* LATIN CAPITAL LETTER Z WITH CARON */
	0xAF, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
	0xB0, /* DEGREE SIGN */
	0xA1, /* LATIN SMALL LETTER A WITH OGONEK */
	0xB2, /* OGONEK */
	0xA3, /* LATIN SMALL LETTER L WITH STROKE */
	0xB4, /* ACUTE ACCENT */
	0xA5, /* LATIN SMALL LETTER L WITH CARON */
	0xA6, /* LATIN SMALL LETTER S WITH ACUTE */
	0xB7, /* CARON */
	0xB8, /* CEDILLA */
	0xA9, /* LATIN SMALL LETTER S WITH CARON */
	0xAA, /* LATIN SMALL LETTER S WITH CEDILLA */
	0xAB, /* LATIN SMALL LETTER T WITH CARON */
	0xAC, /* LATIN SMALL LETTER Z WITH ACUTE */
	0xBD, /* DOUBLE ACUTE ACCENT */
	0xAE, /* LATIN SMALL LETTER Z WITH CARON */
	0xAF, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

	0xC0, /* LATIN CAPITAL LETTER R WITH ACUTE */
	0xC1, /* LATIN CAPITAL LETTER A WITH ACUTE */
	0xC2, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
	0xC3, /* LATIN CAPITAL LETTER A WITH BREVE */
	0xC4, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
	0xC5, /* LATIN CAPITAL LETTER L WITH ACUTE */
	0xC6, /* LATIN CAPITAL LETTER C WITH ACUTE */
	0xC7, /* LATIN CAPITAL LETTER C WITH CEDILLA */
	0xC8, /* LATIN CAPITAL LETTER C WITH CARON */
	0xC9, /* LATIN CAPITAL LETTER E WITH ACUTE */
	0xCA, /* LATIN CAPITAL LETTER E WITH OGONEK */
	0xCB, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
	0xCC, /* LATIN CAPITAL LETTER E WITH CARON */
	0xCD, /* LATIN CAPITAL LETTER I WITH ACUTE */
	0xCE, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
	0xCF, /* LATIN CAPITAL LETTER D WITH CARON */
	0xD0, /* LATIN CAPITAL LETTER D WITH STROKE */
	0xD1, /* LATIN CAPITAL LETTER N WITH ACUTE */
	0xD2, /* LATIN CAPITAL LETTER N WITH CARON */
	0xD3, /* LATIN CAPITAL LETTER O WITH ACUTE */
	0xD4, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
	0xD5, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
	0xD6, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
	0xD7, /* MULTIPLICATION SIGN */
	0xD8, /* LATIN CAPITAL LETTER R WITH CARON */
	0xD9, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
	0xDA, /* LATIN CAPITAL LETTER U WITH ACUTE */
	0xDB, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
	0xDC, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
	0xDD, /* LATIN CAPITAL LETTER Y WITH ACUTE */
	0xDE, /* LATIN CAPITAL LETTER T WITH CEDILLA */
	0xDF, /* LATIN SMALL LETTER SHARP S */

	0xC0, /* LATIN SMALL LETTER R WITH ACUTE */
	0xC1, /* LATIN SMALL LETTER A WITH ACUTE */
	0xC2, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
	0xC3, /* LATIN SMALL LETTER A WITH BREVE */
	0xC4, /* LATIN SMALL LETTER A WITH DIAERESIS */
	0xC5, /* LATIN SMALL LETTER L WITH ACUTE */
	0xC6, /* LATIN SMALL LETTER C WITH ACUTE */
	0xC7, /* LATIN SMALL LETTER C WITH CEDILLA */
	0xC8, /* LATIN SMALL LETTER C WITH CARON */
	0xC9, /* LATIN SMALL LETTER E WITH ACUTE */
	0xCA, /* LATIN SMALL LETTER E WITH OGONEK */
	0xCB, /* LATIN SMALL LETTER E WITH DIAERESIS */
	0xCC, /* LATIN SMALL LETTER E WITH CARON */
	0xCD, /* LATIN SMALL LETTER I WITH ACUTE */
	0xCE, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
	0xCF, /* LATIN SMALL LETTER D WITH CARON */
	0xD0, /* LATIN SMALL LETTER D WITH STROKE */
	0xD1, /* LATIN SMALL LETTER N WITH ACUTE */
	0xD2, /* LATIN SMALL LETTER N WITH CARON */
	0xD3, /* LATIN SMALL LETTER O WITH ACUTE */
	0xD4, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
	0xD5, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
	0xD6, /* LATIN SMALL LETTER O WITH DIAERESIS */
	0xF7, /* DIVISION SIGN */
	0xD8, /* LATIN SMALL LETTER R WITH CARON */
	0xD9, /* LATIN SMALL LETTER U WITH RING ABOVE */
	0xDA, /* LATIN SMALL LETTER U WITH ACUTE */
	0xDB, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
	0xDC, /* LATIN SMALL LETTER U WITH DIAERESIS */
	0xDD, /* LATIN SMALL LETTER Y WITH ACUTE */
	0xDE, /* LATIN SMALL LETTER T WITH CEDILLA */
	0xFF  /* DOT ABOVE */
};

///
/// CzechCollate1[]

// This table SHOULD BE REVISED before using for other languages using
// ISO-8859-2 encoding.

const UBYTE CzechCollate1[256] =
{
	0x00, /* NULL */
	0x01, /* START OF HEADING */
	0x02, /* START OF TEXT */
	0x03, /* END OF TEXT */
	0x04, /* END OF TRANSMISSION */
	0x05, /* ENQUIRY */
	0x06, /* ACKNOWLEDGE */
	0x07, /* BELL */
	0x08, /* BACKSPACE */
	0x09, /* HORIZONTAL TABULATION */
	0x0A, /* LINE FEED */
	0x0B, /* VERTICAL TABULATION */
	0x0C, /* FORM FEED */
	0x0D, /* CARRIAGE RETURN */
	0x0E, /* SHIFT OUT */
	0x0F, /* SHIFT IN */
	0x10, /* DATA LINK ESCAPE */
	0x11, /* DEVICE CONTROL ONE */
	0x12, /* DEVICE CONTROL TWO */
	0x13, /* DEVICE CONTROL THREE */
	0x14, /* DEVICE CONTROL FOUR */
	0x15, /* NEGATIVE ACKNOWLEDGE */
	0x16, /* SYNCHRONOUS IDLE */
	0x17, /* END OF TRANSMISSION BLOCK */
	0x18, /* CANCEL */
	0x19, /* END OF MEDIUM */
	0x1A, /* SUBSTITUTE */
	0x1B, /* ESCAPE */
	0x1C, /* FILE SEPARATOR */
	0x1D, /* GROUP SEPARATOR */
	0x1E, /* RECORD SEPARATOR */
	0x1F, /* UNIT SEPARATOR */

	0x20, /* SPACE */
	0x21, /* EXCLAMATION MARK */
	0x22, /* QUOTATION MARK */
	0x23, /* NUMBER SIGN */
	0x24, /* DOLLAR SIGN */
	0x25, /* PERCENT SIGN */
	0x26, /* AMPERSAND */
	0x27, /* APOSTROPHE */
	0x28, /* LEFT PARENTHESIS */
	0x29, /* RIGHT PARENTHESIS */
	0x2A, /* ASTERISK */
	0x2B, /* PLUS SIGN */
	0x2C, /* COMMA */
	0x2D, /* HYPHEN-MINUS */
	0x2E, /* FULL STOP */
	0x2F, /* SOLIDUS */
	0x30, /* DIGIT ZERO */
	0x31, /* DIGIT ONE */
	0x32, /* DIGIT TWO */
	0x33, /* DIGIT THREE */
	0x34, /* DIGIT FOUR */
	0x35, /* DIGIT FIVE */
	0x36, /* DIGIT SIX */
	0x37, /* DIGIT SEVEN */
	0x38, /* DIGIT EIGHT */
	0x39, /* DIGIT NINE */
	0x3A, /* COLON */
	0x3B, /* SEMICOLON */
	0x3C, /* LESS-THAN SIGN */
	0x3D, /* EQUALS SIGN */
	0x3E, /* GREATER-THAN SIGN */
	0x3F, /* QUESTION MARK */
	0x40, /* COMMERCIAL AT */

	0x41, /* LATIN CAPITAL LETTER A */
	0x42, /* LATIN CAPITAL LETTER B */
	0x43, /* LATIN CAPITAL LETTER C */
	0x44, /* LATIN CAPITAL LETTER D */
	0x45, /* LATIN CAPITAL LETTER E */
	0x46, /* LATIN CAPITAL LETTER F */
	0x47, /* LATIN CAPITAL LETTER G */
	0x48, /* LATIN CAPITAL LETTER H */
	/* 0x49 ... LETTER CH, see LibStrCompare() function */
	0x4A, /* LATIN CAPITAL LETTER I */
	0x4B, /* LATIN CAPITAL LETTER J */
	0x4C, /* LATIN CAPITAL LETTER K */
	0x4D, /* LATIN CAPITAL LETTER L */
	0x4E, /* LATIN CAPITAL LETTER M */
	0x4F, /* LATIN CAPITAL LETTER N */
	0x50, /* LATIN CAPITAL LETTER O */
	0x51, /* LATIN CAPITAL LETTER P */
	0x52, /* LATIN CAPITAL LETTER Q */
	0x53, /* LATIN CAPITAL LETTER R */
	0x54, /* LATIN CAPITAL LETTER S */
	0x55, /* LATIN CAPITAL LETTER T */
	0x56, /* LATIN CAPITAL LETTER U */
	0x57, /* LATIN CAPITAL LETTER V */
	0x58, /* LATIN CAPITAL LETTER W */
	0x59, /* LATIN CAPITAL LETTER X */
	0x5A, /* LATIN CAPITAL LETTER Y */
	0x5B, /* LATIN CAPITAL LETTER Z */

	0x5C, /* LEFT SQUARE BRACKET */
	0x5D, /* REVERSE SOLIDUS */
	0x5E, /* RIGHT SQUARE BRACKET */
	0x5F, /* CIRCUMFLEX ACCENT */
	0x60, /* LOW LINE */
	0x61, /* GRAVE ACCENT */

	0x41, /* LATIN SMALL LETTER A */
	0x42, /* LATIN SMALL LETTER B */
	0x43, /* LATIN SMALL LETTER C */
	0x44, /* LATIN SMALL LETTER D */
	0x45, /* LATIN SMALL LETTER E */
	0x46, /* LATIN SMALL LETTER F */
	0x47, /* LATIN SMALL LETTER G */
	0x48, /* LATIN SMALL LETTER H */
	/* 0x49 ... LETTER CH, see LibStrCompare() function */
	0x4A, /* LATIN SMALL LETTER I */
	0x4B, /* LATIN SMALL LETTER J */
	0x4C, /* LATIN SMALL LETTER K */
	0x4D, /* LATIN SMALL LETTER L */
	0x4E, /* LATIN SMALL LETTER M */
	0x4F, /* LATIN SMALL LETTER N */
	0x50, /* LATIN SMALL LETTER O */
	0x51, /* LATIN SMALL LETTER P */
	0x52, /* LATIN SMALL LETTER Q */
	0x53, /* LATIN SMALL LETTER R */
	0x54, /* LATIN SMALL LETTER S */
	0x55, /* LATIN SMALL LETTER T */
	0x56, /* LATIN SMALL LETTER U */
	0x57, /* LATIN SMALL LETTER V */
	0x58, /* LATIN SMALL LETTER W */
	0x59, /* LATIN SMALL LETTER X */
	0x5A, /* LATIN SMALL LETTER Y */
	0x5B, /* LATIN SMALL LETTER Z */

	0x62, /* LEFT CURLY BRACKET */
	0x63, /* VERTICAL LINE */
	0x64, /* RIGHT CURLY BRACKET */
	0x65, /* TILDE */
	0x66, /* DELETE */

	0x80, /* <control> */
	0x81, /* <control> */
	0x82, /* <control> */
	0x83, /* <control> */
	0x84, /* <control> */
	0x85, /* <control> */
	0x86, /* <control> */
	0x87, /* <control> */
	0x88, /* <control> */
	0x89, /* <control> */
	0x8A, /* <control> */
	0x8B, /* <control> */
	0x8C, /* <control> */
	0x8D, /* <control> */
	0x8E, /* <control> */
	0x8F, /* <control> */
	0x90, /* <control> */
	0x91, /* <control> */
	0x92, /* <control> */
	0x93, /* <control> */
	0x94, /* <control> */
	0x95, /* <control> */
	0x96, /* <control> */
	0x97, /* <control> */
	0x98, /* <control> */
	0x99, /* <control> */
	0x9A, /* <control> */
	0x9B, /* <control> */
	0x9C, /* <control> */
	0x9D, /* <control> */
	0x9E, /* <control> */
	0x9F, /* <control> */

	0x20, /* NO-BREAK SPACE */ /* I think leaving the value 160 for this is wrong */
	0x41, /* LATIN CAPITAL LETTER A WITH OGONEK */
	0xA2, /* BREVE */
	0x4D, /* LATIN CAPITAL LETTER L WITH STROKE */
	0xA4, /* CURRENCY SIGN */
	0x4C, /* LATIN CAPITAL LETTER L WITH CARON */
	0x54, /* LATIN CAPITAL LETTER S WITH ACUTE */
	0xA7, /* SECTION SIGN */
	0xA8, /* DIAERESIS */
	0x54, /* LATIN CAPITAL LETTER S WITH CARON */
	0x54, /* LATIN CAPITAL LETTER S WITH CEDILLA */
	0x55, /* LATIN CAPITAL LETTER T WITH CARON */
	0x5B, /* LATIN CAPITAL LETTER Z WITH ACUTE */
	0xAD, /* SOFT HYPHEN */
	0x5B, /* LATIN CAPITAL LETTER Z WITH CARON */
	0x5B, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
	0xB0, /* DEGREE SIGN */
	0x41, /* LATIN SMALL LETTER A WITH OGONEK */
	0xB2, /* OGONEK */
	0x4D, /* LATIN SMALL LETTER L WITH STROKE */
	0xB4, /* ACUTE ACCENT */
	0x4D, /* LATIN SMALL LETTER L WITH CARON */
	0x54, /* LATIN SMALL LETTER S WITH ACUTE */
	0xB7, /* CARON */
	0xB8, /* CEDILLA */
	0x54, /* LATIN SMALL LETTER S WITH CARON */
	0x54, /* LATIN SMALL LETTER S WITH CEDILLA */
	0x55, /* LATIN SMALL LETTER T WITH CARON */
	0x5B, /* LATIN SMALL LETTER Z WITH ACUTE */
	0xBD, /* DOUBLE ACUTE ACCENT */
	0x5B, /* LATIN SMALL LETTER Z WITH CARON */
	0x5B, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

	0x53, /* LATIN CAPITAL LETTER R WITH ACUTE */
	0x41, /* LATIN CAPITAL LETTER A WITH ACUTE */
	0x41, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
	0x41, /* LATIN CAPITAL LETTER A WITH BREVE */
	0x41, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
	0x4D, /* LATIN CAPITAL LETTER L WITH ACUTE */
	0x43, /* LATIN CAPITAL LETTER C WITH ACUTE */
	0x43, /* LATIN CAPITAL LETTER C WITH CEDILLA */
	0x43, /* LATIN CAPITAL LETTER C WITH CARON */
	0x45, /* LATIN CAPITAL LETTER E WITH ACUTE */
	0x45, /* LATIN CAPITAL LETTER E WITH OGONEK */
	0x45, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
	0x45, /* LATIN CAPITAL LETTER E WITH CARON */
	0x4A, /* LATIN CAPITAL LETTER I WITH ACUTE */
	0x4A, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
	0x44, /* LATIN CAPITAL LETTER D WITH CARON */
	0x44, /* LATIN CAPITAL LETTER D WITH STROKE */
	0x4F, /* LATIN CAPITAL LETTER N WITH ACUTE */
	0x4F, /* LATIN CAPITAL LETTER N WITH CARON */
	0x50, /* LATIN CAPITAL LETTER O WITH ACUTE */
	0x50, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
	0x50, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
	0x50, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
	0xD7, /* MULTIPLICATION SIGN */
	0x53, /* LATIN CAPITAL LETTER R WITH CARON */
	0x56, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
	0x56, /* LATIN CAPITAL LETTER U WITH ACUTE */
	0x56, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
	0x56, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
	0x5A, /* LATIN CAPITAL LETTER Y WITH ACUTE */
	0x55, /* LATIN CAPITAL LETTER T WITH CEDILLA */
	0xDF, /* LATIN SMALL LETTER SHARP S */

	0x53, /* LATIN SMALL LETTER R WITH ACUTE */
	0x41, /* LATIN SMALL LETTER A WITH ACUTE */
	0x41, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
	0x41, /* LATIN SMALL LETTER A WITH BREVE */
	0x41, /* LATIN SMALL LETTER A WITH DIAERESIS */
	0x4D, /* LATIN SMALL LETTER L WITH ACUTE */
	0x43, /* LATIN SMALL LETTER C WITH ACUTE */
	0x43, /* LATIN SMALL LETTER C WITH CEDILLA */
	0x43, /* LATIN SMALL LETTER C WITH CARON */
	0x45, /* LATIN SMALL LETTER E WITH ACUTE */
	0x45, /* LATIN SMALL LETTER E WITH OGONEK */
	0x45, /* LATIN SMALL LETTER E WITH DIAERESIS */
	0x45, /* LATIN SMALL LETTER E WITH CARON */
	0x4A, /* LATIN SMALL LETTER I WITH ACUTE */
	0x4A, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
	0x44, /* LATIN SMALL LETTER D WITH CARON */
	0x44, /* LATIN SMALL LETTER D WITH STROKE */
	0x4F, /* LATIN SMALL LETTER N WITH ACUTE */
	0x4F, /* LATIN SMALL LETTER N WITH CARON */
	0x50, /* LATIN SMALL LETTER O WITH ACUTE */
	0x50, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
	0x50, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
	0x50, /* LATIN SMALL LETTER O WITH DIAERESIS */
	0xF7, /* DIVISION SIGN */
	0x53, /* LATIN SMALL LETTER R WITH CARON */
	0x56, /* LATIN SMALL LETTER U WITH RING ABOVE */
	0x56, /* LATIN SMALL LETTER U WITH ACUTE */
	0x56, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
	0x56, /* LATIN SMALL LETTER U WITH DIAERESIS */
	0x5A, /* LATIN SMALL LETTER Y WITH ACUTE */
	0x55, /* LATIN SMALL LETTER T WITH CEDILLA */
	0xFF  /* DOT ABOVE */
};

///
/// CzechCollate2[]

// This table SHOULD NOT be used without changes in languages using ISO-8859-2
// encoding other than Czech. Collating order for accented characters is
// defined here as following:
//
// - character without accent,
// - character with acute (if exists),
// - character with ring above (if exists),
// - character with double acute (if exists),
// - character with circumflex (if exists),
// - character with breve (if exists),
// - character with dieresis (if exists),
// - character with caron (if exists),
// - character with cedilla (if exists).
//
//  This order is probably not right for any language except Czech. [luky]

const UBYTE CzechCollate2[256] =
{
	0x00, /* NULL */
	0x01, /* START OF HEADING */
	0x02, /* START OF TEXT */
	0x03, /* END OF TEXT */
	0x04, /* END OF TRANSMISSION */
	0x05, /* ENQUIRY */
	0x06, /* ACKNOWLEDGE */
	0x07, /* BELL */
	0x08, /* BACKSPACE */
	0x09, /* HORIZONTAL TABULATION */
	0x0A, /* LINE FEED */
	0x0B, /* VERTICAL TABULATION */
	0x0C, /* FORM FEED */
	0x0D, /* CARRIAGE RETURN */
	0x0E, /* SHIFT OUT */
	0x0F, /* SHIFT IN */
	0x10, /* DATA LINK ESCAPE */
	0x11, /* DEVICE CONTROL ONE */
	0x12, /* DEVICE CONTROL TWO */
	0x13, /* DEVICE CONTROL THREE */
	0x14, /* DEVICE CONTROL FOUR */
	0x15, /* NEGATIVE ACKNOWLEDGE */
	0x16, /* SYNCHRONOUS IDLE */
	0x17, /* END OF TRANSMISSION BLOCK */
	0x18, /* CANCEL */
	0x19, /* END OF MEDIUM */
	0x1A, /* SUBSTITUTE */
	0x1B, /* ESCAPE */
	0x1C, /* FILE SEPARATOR */
	0x1D, /* GROUP SEPARATOR */
	0x1E, /* RECORD SEPARATOR */
	0x1F, /* UNIT SEPARATOR */

	0x20, /* SPACE */
	0x21, /* EXCLAMATION MARK */
	0x22, /* QUOTATION MARK */
	0x23, /* NUMBER SIGN */
	0x24, /* DOLLAR SIGN */
	0x25, /* PERCENT SIGN */
	0x26, /* AMPERSAND */
	0x27, /* APOSTROPHE */
	0x28, /* LEFT PARENTHESIS */
	0x29, /* RIGHT PARENTHESIS */
	0x2A, /* ASTERISK */
	0x2B, /* PLUS SIGN */
	0x2C, /* COMMA */
	0x2D, /* HYPHEN-MINUS */
	0x2E, /* FULL STOP */
	0x2F, /* SOLIDUS */
	0x30, /* DIGIT ZERO */
	0x31, /* DIGIT ONE */
	0x32, /* DIGIT TWO */
	0x33, /* DIGIT THREE */
	0x34, /* DIGIT FOUR */
	0x35, /* DIGIT FIVE */
	0x36, /* DIGIT SIX */
	0x37, /* DIGIT SEVEN */
	0x38, /* DIGIT EIGHT */
	0x39, /* DIGIT NINE */
	0x3A, /* COLON */
	0x3B, /* SEMICOLON */
	0x3C, /* LESS-THAN SIGN */
	0x3D, /* EQUALS SIGN */
	0x3E, /* GREATER-THAN SIGN */
	0x3F, /* QUESTION MARK */
	0x40, /* COMMERCIAL AT */

	0x41, /* LATIN CAPITAL LETTER A */
	0x47, /* LATIN CAPITAL LETTER B */
	0x48, /* LATIN CAPITAL LETTER C */
	0x4C, /* LATIN CAPITAL LETTER D */
	0x4F, /* LATIN CAPITAL LETTER E */
	0x54, /* LATIN CAPITAL LETTER F */
	0x55, /* LATIN CAPITAL LETTER G */
	0x56, /* LATIN CAPITAL LETTER H */
	/* 0x57 ... LETTER CH, see LibStrCompare() function */
	0x58, /* LATIN CAPITAL LETTER I */
	0x5A, /* LATIN CAPITAL LETTER J */
	0x5B, /* LATIN CAPITAL LETTER K */
	0x5C, /* LATIN CAPITAL LETTER L */
	0x6A, /* LATIN CAPITAL LETTER M */
	0x6B, /* LATIN CAPITAL LETTER N */
	0x64, /* LATIN CAPITAL LETTER O */
	0x69, /* LATIN CAPITAL LETTER P */
	0x6A, /* LATIN CAPITAL LETTER Q */
	0x6B, /* LATIN CAPITAL LETTER R */
	0x6E, /* LATIN CAPITAL LETTER S */
	0x72, /* LATIN CAPITAL LETTER T */
	0x75, /* LATIN CAPITAL LETTER U */
	0x7A, /* LATIN CAPITAL LETTER V */
	0x7B, /* LATIN CAPITAL LETTER W */
	0x7C, /* LATIN CAPITAL LETTER X */
	0x7D, /* LATIN CAPITAL LETTER Y */
	0x7F, /* LATIN CAPITAL LETTER Z */

	0x81, /* LEFT SQUARE BRACKET */
	0x82, /* REVERSE SOLIDUS */
	0x83, /* RIGHT SQUARE BRACKET */
	0x84, /* CIRCUMFLEX ACCENT */
	0x85, /* LOW LINE */

	0x60, /* GRAVE ACCENT */
	0x41, /* LATIN SMALL LETTER A */
	0x47, /* LATIN SMALL LETTER B */
	0x48, /* LATIN SMALL LETTER C */
	0x4C, /* LATIN SMALL LETTER D */
	0x4F, /* LATIN SMALL LETTER E */
	0x54, /* LATIN SMALL LETTER F */
	0x55, /* LATIN SMALL LETTER G */
	0x56, /* LATIN SMALL LETTER H */
	/* 0x57 ... LETTER CH, see LibStrCompare() function */
	0x58, /* LATIN SMALL LETTER I */
	0x5A, /* LATIN SMALL LETTER J */
	0x5B, /* LATIN SMALL LETTER K */
	0x5C, /* LATIN SMALL LETTER L */
	0x6A, /* LATIN SMALL LETTER M */
	0x6B, /* LATIN SMALL LETTER N */
	0x64, /* LATIN SMALL LETTER O */
	0x69, /* LATIN SMALL LETTER P */
	0x6A, /* LATIN SMALL LETTER Q */
	0x6B, /* LATIN SMALL LETTER R */
	0x6E, /* LATIN SMALL LETTER S */
	0x72, /* LATIN SMALL LETTER T */
	0x75, /* LATIN SMALL LETTER U */
	0x7A, /* LATIN SMALL LETTER V */
	0x7B, /* LATIN SMALL LETTER W */
	0x7C, /* LATIN SMALL LETTER X */
	0x7D, /* LATIN SMALL LETTER Y */
	0x7F, /* LATIN SMALL LETTER Z */
	0x86, /* LEFT CURLY BRACKET */
	0x87, /* VERTICAL LINE */
	0x88, /* RIGHT CURLY BRACKET */
	0x89, /* TILDE */
	0x8A, /* DELETE */

	0x8B, /* <control> */
	0x8C, /* <control> */
	0x8D, /* <control> */
	0x8E, /* <control> */
	0x8F, /* <control> */
	0x90, /* <control> */
	0x91, /* <control> */
	0x92, /* <control> */
	0x93, /* <control> */
	0x94, /* <control> */
	0x95, /* <control> */
	0x96, /* <control> */
	0x97, /* <control> */
	0x98, /* <control> */
	0x99, /* <control> */
	0x9A, /* <control> */
	0x9B, /* <control> */
	0x9C, /* <control> */
	0x9D, /* <control> */
	0x9E, /* <control> */
	0x9F, /* <control> */
	0xA0, /* <control> */
	0xA1, /* <control> */
	0xA2, /* <control> */
	0xA3, /* <control> */
	0xA4, /* <control> */
	0xA5, /* <control> */
	0xA6, /* <control> */
	0xA7, /* <control> */
	0xA8, /* <control> */
	0xA9, /* <control> */
	0xAA, /* <control> */

	0x20, /* NO-BREAK SPACE */
	0x42, /* LATIN CAPITAL LETTER A WITH OGONEK */
	0xAB, /* BREVE */
	0x5D, /* LATIN CAPITAL LETTER L WITH STROKE */
	0xAC, /* CURRENCY SIGN */
	0x5F, /* LATIN CAPITAL LETTER L WITH CARON */
	0x6F, /* LATIN CAPITAL LETTER S WITH ACUTE */
	0xAD, /* SECTION SIGN */
	0xAE, /* DIAERESIS */
	0x70, /* LATIN CAPITAL LETTER S WITH CARON */
	0x71, /* LATIN CAPITAL LETTER S WITH CEDILLA */
	0x73, /* LATIN CAPITAL LETTER T WITH CARON */
	0x80, /* LATIN CAPITAL LETTER Z WITH ACUTE */
	0xAF, /* SOFT HYPHEN */
	0x82, /* LATIN CAPITAL LETTER Z WITH CARON */
	0x81, /* LATIN CAPITAL LETTER Z WITH DOT ABOVE */
	0xB0, /* DEGREE SIGN */
	0x42, /* LATIN SMALL LETTER A WITH OGONEK */
	0xB1, /* OGONEK */
	0x5D, /* LATIN SMALL LETTER L WITH STROKE */
	0xB2, /* ACUTE ACCENT */
	0x5F, /* LATIN SMALL LETTER L WITH CARON */
	0x6F, /* LATIN SMALL LETTER S WITH ACUTE */
	0xB3, /* CARON */
	0xB4, /* CEDILLA */
	0x70, /* LATIN SMALL LETTER S WITH CARON */
	0x71, /* LATIN SMALL LETTER S WITH CEDILLA */
	0x73, /* LATIN SMALL LETTER T WITH CARON */
	0x80, /* LATIN SMALL LETTER Z WITH ACUTE */
	0xB5, /* DOUBLE ACUTE ACCENT */
	0x82, /* LATIN SMALL LETTER Z WITH CARON */
	0x81, /* LATIN SMALL LETTER Z WITH DOT ABOVE */

	0x6C, /* LATIN CAPITAL LETTER R WITH ACUTE */
	0x43, /* LATIN CAPITAL LETTER A WITH ACUTE */
	0x44, /* LATIN CAPITAL LETTER A WITH CIRCUMFLEX */
	0x45, /* LATIN CAPITAL LETTER A WITH BREVE */
	0x46, /* LATIN CAPITAL LETTER A WITH DIAERESIS */
	0x5E, /* LATIN CAPITAL LETTER L WITH ACUTE */
	0x49, /* LATIN CAPITAL LETTER C WITH ACUTE */
	0x4A, /* LATIN CAPITAL LETTER C WITH CEDILLA */
	0x4B, /* LATIN CAPITAL LETTER C WITH CARON */
	0x51, /* LATIN CAPITAL LETTER E WITH ACUTE */
	0x50, /* LATIN CAPITAL LETTER E WITH OGONEK */
	0x52, /* LATIN CAPITAL LETTER E WITH DIAERESIS */
	0x53, /* LATIN CAPITAL LETTER E WITH CARON */
	0x59, /* LATIN CAPITAL LETTER I WITH ACUTE */
	0x59, /* LATIN CAPITAL LETTER I WITH CIRCUMFLEX */
	0x4D, /* LATIN CAPITAL LETTER D WITH CARON */
	0x4E, /* LATIN CAPITAL LETTER D WITH STROKE */
	0x62, /* LATIN CAPITAL LETTER N WITH ACUTE */
	0x63, /* LATIN CAPITAL LETTER N WITH CARON */
	0x65, /* LATIN CAPITAL LETTER O WITH ACUTE */
	0x66, /* LATIN CAPITAL LETTER O WITH CIRCUMFLEX */
	0x67, /* LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
	0x68, /* LATIN CAPITAL LETTER O WITH DIAERESIS */
	0xB6, /* MULTIPLICATION SIGN */
	0x6D, /* LATIN CAPITAL LETTER R WITH CARON */
	0x77, /* LATIN CAPITAL LETTER U WITH RING ABOVE */
	0x76, /* LATIN CAPITAL LETTER U WITH ACUTE */
	0x78, /* LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
	0x79, /* LATIN CAPITAL LETTER U WITH DIAERESIS */
	0x7E, /* LATIN CAPITAL LETTER Y WITH ACUTE */
	0x74, /* LATIN CAPITAL LETTER T WITH CEDILLA */
	0xB7, /* LATIN SMALL LETTER SHARP S */

	0x6C, /* LATIN SMALL LETTER R WITH ACUTE */
	0x43, /* LATIN SMALL LETTER A WITH ACUTE */
	0x44, /* LATIN SMALL LETTER A WITH CIRCUMFLEX */
	0x45, /* LATIN SMALL LETTER A WITH BREVE */
	0x46, /* LATIN SMALL LETTER A WITH DIAERESIS */
	0x5E, /* LATIN SMALL LETTER L WITH ACUTE */
	0x49, /* LATIN SMALL LETTER C WITH ACUTE */
	0x4A, /* LATIN SMALL LETTER C WITH CEDILLA */
	0x4B, /* LATIN SMALL LETTER C WITH CARON */
	0x51, /* LATIN SMALL LETTER E WITH ACUTE */
	0x50, /* LATIN SMALL LETTER E WITH OGONEK */
	0x52, /* LATIN SMALL LETTER E WITH DIAERESIS */
	0x53, /* LATIN SMALL LETTER E WITH CARON */
	0x59, /* LATIN SMALL LETTER I WITH ACUTE */
	0x59, /* LATIN SMALL LETTER I WITH CIRCUMFLEX */
	0x4D, /* LATIN SMALL LETTER D WITH CARON */
	0x4E, /* LATIN SMALL LETTER D WITH STROKE */
	0x62, /* LATIN SMALL LETTER N WITH ACUTE */
	0x63, /* LATIN SMALL LETTER N WITH CARON */
	0x65, /* LATIN SMALL LETTER O WITH ACUTE */
	0x66, /* LATIN SMALL LETTER O WITH CIRCUMFLEX */
	0x67, /* LATIN SMALL LETTER O WITH DOUBLE ACUTE */
	0x68, /* LATIN SMALL LETTER O WITH DIAERESIS */
	0xB8, /* DIVISION SIGN */
	0x6D, /* LATIN SMALL LETTER R WITH CARON */
	0x77, /* LATIN SMALL LETTER U WITH RING ABOVE */
	0x76, /* LATIN SMALL LETTER U WITH ACUTE */
	0x78, /* LATIN SMALL LETTER U WITH DOUBLE ACUTE */
	0x79, /* LATIN SMALL LETTER U WITH DIAERESIS */
	0x7E, /* LATIN SMALL LETTER Y WITH ACUTE */
	0x74, /* LATIN SMALL LETTER T WITH CEDILLA */
	0xB9  /* DOT ABOVE */
};

///
